@@ -1,12 +1,14 @@
 package Dancer::Template::Tenjin;
-BEGIN {
-  $Dancer::Template::Tenjin::VERSION = '0.4';
-}
+
+# ABSTRACT: Tenjin wrapper for Dancer
 
 use strict;
 use warnings;
 
-use Tenjin;
+our $VERSION = "0.5";
+$VERSION = eval $VERSION;
+
+use Tenjin 0.070001;
 use Dancer::Config 'setting';
 use File::Basename;
 use Try::Tiny;
@@ -14,15 +16,13 @@ use Carp;
 
 use base 'Dancer::Template::Abstract';
 
-# ABSTRACT: Tenjin wrapper for Dancer
-
 =head1 NAME
 
 Dancer::Template::Tenjin - Tenjin wrapper for Dancer
 
 =head1 VERSION
 
-version 0.4
+version 0.5
 
 =head1 SYNOPSIS
 
@@ -31,6 +31,10 @@ version 0.4
 
 	# note: templates must use the '.tt' extension
 
+	# you might also want to add (if your templates are UTF-8, which is the
+	# default encoding used by Tenjin):
+	charset: "UTF-8"
+
 =head1 DESCRIPTION
 
 This class is an interface between Dancer's template engine abstraction layer
@@ -62,15 +66,7 @@ Initializes a template engine by generating a new instance of L<Tenjin>.
 =cut
 
 sub init {
-	my $self = shift;
-
-	# set Tenjin configuration options
-	my $conf = { postfix => '.tt' };
-
-	$conf->{path} = [setting('views')];
-
-	# get an instance of Tenjin
-	$self->{engine} = Tenjin->new($conf);
+	$_[0]->{engine} = Tenjin->new({ postfix => '.tt', path => [setting('views')] });
 }
 
 =head2 render( $template, $tokens )
@@ -84,7 +80,9 @@ sub render($$$) {
 	my ($self, $template, $tokens) = @_;
 
 	croak "'$template' is not a regular file"
-		if !ref($template) && (!-f $template);
+		if !ref $template && !-f $template;
+
+	$tokens ||= {};
 
 	# Dancer seems to be sending the full filename (i.e. including full path)
 	# of the template, while we only need the relative path, so let's
@@ -101,12 +99,11 @@ sub render($$$) {
 	# ignore 'bad' tokens - this is here because for some reason
 	# Dancer is passing the entire user agent as a token, and I can't
 	# find the cause of that yet.
-	my %vars = %$tokens;
-	foreach (keys %vars) {
-		delete $vars{$_} if m/[ ()]/;
+	foreach (keys %$tokens) {
+		delete $tokens->{$_} if m/[ ()]/;
 	}
 
-	my $output = try { $self->{engine}->render($template, \%vars) } catch { croak $_ };
+	my $output = try { $self->{engine}->render($template, $tokens) } catch { croak $_ };
 	return $output;
 }
 
@@ -188,7 +185,7 @@ L<http://search.cpan.org/dist/Dancer-Template-Tenjin/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Ido Perlmuter.
+Copyright 2010-2011 Ido Perlmuter.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
